@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Header: /Users/claude/fuzz/lib/Genezzo/BufCa/RCS/BufCa.pm,v 6.2 2004/12/14 07:51:38 claude Exp claude $
+# $Header: /Users/claude/fuzz/lib/Genezzo/BufCa/RCS/BufCa.pm,v 6.3 2005/07/08 09:30:12 claude Exp claude $
 #
 # copyright (c) 2003, 2004 Jeffrey I Cohen, all rights reserved, worldwide
 #
@@ -24,7 +24,7 @@ BEGIN {
     # set the version for version checking
 #    $VERSION     = 1.00;
     # if using RCS/CVS, this may be preferred
-    $VERSION = do { my @r = (q$Revision: 6.2 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
+    $VERSION = do { my @r = (q$Revision: 6.3 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
 
     @ISA         = qw(Exporter);
 #    @EXPORT      = qw(&func1 &func2 &func4 &func5);
@@ -347,7 +347,7 @@ sub WriteBlock
     sysseek ($fh, ($blknum * $Genezzo::Util::DEFBLOCKSIZE), 0 )
         or die "bad seek - block $blknum : $! \n";
 
-    syswrite ($fh, $$refbuf, $Genezzo::Util::DEFBLOCKSIZE )
+    gnz_write ($fh, $$refbuf, $Genezzo::Util::DEFBLOCKSIZE )
         == $Genezzo::Util::DEFBLOCKSIZE
         or die "bad write - block $blknum : $! \n";
     }
